==> ws-thredds-0.1.0-4.10.0-162203-src.zip: src/test/java/org/gcube/usecases/ws/thredds/FileAccessTests.java <==
package org.gcube.usecases.ws.thredds;

import org.gcube.usecases.ws.thredds.faults.RemoteFileNotFoundException;
import org.gcube.usecases.ws.thredds.faults.UnableToLockException;

public class FileAccessTests {

	public static void main(String[] args) throws RemoteFileNotFoundException, UnableToLockException {
		TokenSetter.set("/gcube/devsec/devVRE");
		
		Runnable readCatalog=new Runnable() {@Override public void run() {	try{
					Commons.readThreddsFile("catalog.xml");
				
		}catch(Throwable t) {System.err.println(t);	}}};
			
		
		Runnable readInfo=new Runnable() {@Override public void run() {	try{
			Commons.getThreddsInfo();		
}catch(Throwable t) {System.err.println(t);	}}};
		
		
		repeatedTimedOperation(readCatalog,"READ CATALOG");
		
		repeatedTimedOperation(readInfo, "READ INFO");
		
		
		System.out.println("Checking lock ..");
				
		String processID="stupidProcess";
		String toLockFolder="devVRE";
		String lockPath=toLockFolder+"/"+Constants.LOCK_FILE;
		
		try {
			Commons.lockFolder(toLockFolder, processID);			
		}catch(UnableToLockException e) {
			System.out.println("Dirty from previous tests.. removing lock..");
			Commons.deleteThreddsFile(lockPath);
			System.out.println("Trying to lock again..");
			Commons.lockFolder(toLockFolder, processID);
		}
		
		try{
			System.out.println("Ok, next should fail...");
			Commons.lockFolder(toLockFolder, processID);
		}catch(UnableToLockException e) {
			System.out.println("Correctly failed, now we read lock.. ");
			
			String lockId=Commons.readThreddsFile(lockPath);
			if(lockId.equals(processID)) {
				System.out.println("Lock owned. Going to remove it.. ");
				Commons.deleteThreddsFile(lockPath);
				System.out.println("Now I can lock it again... ");
				Commons.lockFolder(toLockFolder, processID);
				System.out.println("Ok, cleaning it up.. ");
				Commons.deleteThreddsFile(lockPath);
			}else throw new RuntimeException("LOCK ID "+lockId+" IS DIFFERENT then expected "+processID);
		}
		
		
	}

	
	private static void repeatedTimedOperation(Runnable op,String title) {
		System.out.println(title);
		for(int i=0;i<10;i++)	{
			long startTime=System.currentTimeMillis();
			op.run();
			System.out.println("["+i+"] in "+(System.currentTimeMillis()-startTime));			
		}
		
	}
	
}

==> ws-thredds-0.2.1-4.13.1-169999-src.zip: src/test/java/org/gcube/usecases/ws/thredds/FileAccessTests.java <==
package org.gcube.usecases.ws.thredds;

import org.gcube.usecases.ws.thredds.engine.impl.ThreddsController;
import org.gcube.usecases.ws.thredds.faults.InternalException;
import org.gcube.usecases.ws.thredds.faults.UnableToLockException;

public class FileAccessTests {

	public static void main(String[] args) throws InternalException {
		TestCommons.setScope();
		String processID="stupidProcess";
		String toLockFolder="devVRE";
		
		final ThreddsController controller=new ThreddsController(toLockFolder, TokenSetter.getCurrentToken());
		
		Runnable readCatalog=new Runnable() {@Override public void run() {	try{
					controller.readThreddsFile("catalog.xml");
				
		}catch(Throwable t) {System.err.println(t);	}}};
			
		
		Runnable readInfo=new Runnable() {@Override public void run() {	try{
			controller.getThreddsInfo();		
}catch(Throwable t) {System.err.println(t);	}}};
		

		repeatedTimedOperation(readCatalog,"READ CATALOG");
		
		repeatedTimedOperation(readInfo, "READ INFO");
		
		
		System.out.println("Checking lock ..");
				
		
		
		try {
			controller.lockFolder(processID);			
		}catch(UnableToLockException e) {
			System.out.println("Dirty from previous tests.. removing lock..");
			controller.deleteThreddsFile(Constants.LOCK_FILE);
			System.out.println("Trying to lock again..");
			controller.lockFolder(processID);
		}
		
		try{
			System.out.println("Reading file descriptor... ");
			System.out.println(controller.getFileDescriptor(Constants.LOCK_FILE));
			System.out.println("Ok, next should fail...");
			controller.lockFolder(processID);
		}catch(UnableToLockException e) {
			System.out.println("Correctly failed, now we read lock.. ");
			
			String lockId=controller.readThreddsFile(Constants.LOCK_FILE);
			if(lockId.equals(processID)) {
				System.out.println("Lock owned. Going to remove it.. ");
				controller.deleteThreddsFile(Constants.LOCK_FILE);
				System.out.println("Now I can lock it again... ");
				controller.lockFolder(processID);
				System.out.println("Ok, cleaning it up.. ");
				controller.deleteThreddsFile(Constants.LOCK_FILE);
			}else throw new RuntimeException("LOCK ID "+lockId+" IS DIFFERENT then expected "+processID);
		}
		
		
	}

	
	private static void repeatedTimedOperation(Runnable op,String title) {
		System.out.println(title);
		for(int i=0;i<10;i++)	{
			long startTime=System.currentTimeMillis();
			op.run();
			System.out.println("["+i+"] in "+(System.currentTimeMillis()-startTime));			
		}
		
	}
	
}
